@@ -1,14 +1,21 @@
+from .course_pb2 import *
 from .material_service_http import *
 from .problem_service_pb2 import *
-from .student_service_http import *
-from .student_service_pb2 import *
-from .module_pb2 import *
-from .material_pb2 import *
-from .course_service_http import *
-from .student_pb2 import *
-from .module_service_pb2 import *
-from .problem_service_http import *
 from .course_service_pb2 import *
-from .course_pb2 import *
+from .assignment_pb2 import *
+from .submission_service_pb2 import *
+from .module_pb2 import *
+from .problem_service_http import *
+from .material_pb2 import *
+from .student_service_pb2 import *
+from .class_service_http import *
+from .student_service_http import *
+from .module_service_pb2 import *
+from .course_service_http import *
 from .material_service_pb2 import *
 from .module_service_http import *
+from .events_pb2 import *
+from .submission_service_http import *
+from .student_pb2 import *
+from .class_pb2 import *
+from .class_service_pb2 import *
