@@ -1,31 +1,39 @@
-from .announcement_pb2 import *
-from .participant_service_pb2 import *
-from .problem_pb2 import *
-from .contest_service_http import *
-from .problem_service_pb2 import *
-from .announcement_service_pb2 import *
-from .registration_service_http import *
-from .score_service_pb2 import *
-from .activity_pb2 import *
-from .medal_pb2 import *
-from .ticket_service_http import *
-from .ticket_pb2 import *
-from .ticket_reply_pb2 import *
-from .submission_service_http import *
-from .participant_pb2 import *
-from .announcement_service_http import *
-from .contest_pb2 import *
-from .ticket_service_pb2 import *
-from .events_pb2 import *
-from .result_pb2 import *
-from .registration_service_pb2 import *
+from .passcode_service_http import *
 from .contest_service_pb2 import *
-from .judge_http import *
-from .score_pb2 import *
-from .participant_service_http import *
-from .problem_service_http import *
-from .score_service_http import *
-from .submission_pb2 import *
-from .template_pb2 import *
-from .judge_pb2 import *
+from .admission_service_pb2 import *
+from .contest_pb2 import *
+from .admission_service_http import *
+from .violation_pb2 import *
+from .announcement_service_pb2 import *
+from .announcement_pb2 import *
+from .problem_service_pb2 import *
+from .ticket_pb2 import *
 from .submission_service_pb2 import *
+from .ticket_service_pb2 import *
+from .ticket_service_http import *
+from .result_pb2 import *
+from .problem_service_http import *
+from .scoreboard_service_http import *
+from .participant_pb2 import *
+from .registration_service_http import *
+from .registration_service_pb2 import *
+from .participant_service_pb2 import *
+from .violation_service_pb2 import *
+from .medal_pb2 import *
+from .violation_service_http import *
+from .passcode_service_pb2 import *
+from .problem_pb2 import *
+from .scoreboard_service_pb2 import *
+from .score_service_pb2 import *
+from .score_pb2 import *
+from .template_pb2 import *
+from .activity_pb2 import *
+from .contest_service_http import *
+from .submission_pb2 import *
+from .ticket_reply_pb2 import *
+from .events_pb2 import *
+from .scoreboard_pb2 import *
+from .submission_service_http import *
+from .score_service_http import *
+from .participant_service_http import *
+from .announcement_service_http import *
