@@ -1,6 +1,8 @@
-from .activity_pb2 import *
-from .ranker_pb2 import *
+from .ranker_http import *
 from .format_pb2 import *
+from .scoreboard_service_http import *
+from .ranker_pb2 import *
+from .scoreboard_service_pb2 import *
+from .activity_pb2 import *
 from .events_pb2 import *
 from .scoreboard_pb2 import *
-from .ranker_http import *
